<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="100px">
      <el-form-item label="数据中心ID" prop="baseId">
        <el-input
          v-model="queryParams.baseId"
          placeholder="请输入数据中心"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="用户" prop="createUser">
        <el-input
          v-model="queryParams.createUser"
          placeholder="请输入创建者"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['bis:useTransport:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['bis:useTransport:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['bis:useTransport:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['bis:useTransport:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="useTransportList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="序号" align="center" prop="id" />
      <el-table-column label="数据中心ID" align="center" prop="baseId" />
      <el-table-column label="日期节点" align="center" prop="dateNode" />
      <el-table-column label="算力中心网络出口带宽" align="center" prop="idcBandwidthExport" />
      <el-table-column label="算力中心内IB技术部署率" align="center" prop="idcIbRate" />
      <el-table-column label="算力中心内RoCE等技术部署率" align="center" prop="idcRoceRate" />
      <el-table-column label="算力中心内全光交换技术部署率" align="center" prop="idcOpticalRate" />
      <el-table-column label="排序" align="center" prop="Sort" v-if="false"/>
      <el-table-column label="更新者" align="center" prop="updateUser" v-if="false"/>
      <el-table-column label="提交者" align="center" prop="createUser" />
      <el-table-column label="管理员备注" align="center" prop="remark" v-if="false" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['bis:useTransport:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['bis:useTransport:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改运力指标信息对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="数据中心ID" prop="baseId">
          <el-input v-model="form.baseId" placeholder="请输入数据中心ID" />
        </el-form-item>
        <el-form-item label="日期节点" prop="dateNode">
          <el-input v-model="form.dateNode" placeholder="请输入日期节点" />
        </el-form-item>
        <el-form-item label="算力中心网络出口带宽" prop="idcBandwidthExport">
          <el-input v-model="form.idcBandwidthExport" placeholder="请输入算力中心网络出口带宽" />
        </el-form-item>
        <el-form-item label="算力中心内IB技术部署率" prop="idcIbRate">
          <el-input v-model="form.idcIbRate" placeholder="请输入算力中心内IB技术部署率" />
        </el-form-item>
        <el-form-item label="算力中心内RoCE等技术部署率" prop="idcRoceRate">
          <el-input v-model="form.idcRoceRate" placeholder="请输入算力中心内RoCE等技术部署率" />
        </el-form-item>
        <el-form-item label="算力中心内全光交换技术部署率" prop="idcOpticalRate">
          <el-input v-model="form.idcOpticalRate" placeholder="请输入算力中心内全光交换技术部署率" />
        </el-form-item>
        <el-form-item label="排序" prop="Sort">
          <el-input v-model="form.Sort" placeholder="请输入排序" />
        </el-form-item>
        <el-form-item label="更新者" prop="updateUser">
          <el-input v-model="form.updateUser" placeholder="请输入更新者" />
        </el-form-item>
        <el-form-item label="创建者" prop="createUser">
          <el-input v-model="form.createUser" placeholder="请输入创建者" />
        </el-form-item>
        <el-form-item label="管理员备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入管理员备注" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listUseTransport, getUseTransport, delUseTransport, addUseTransport, updateUseTransport } from "@/api/bis/useTransport";

export default {
  name: "UseTransport",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 运力指标信息表格数据
      useTransportList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        baseId: null,
        dateNode: null,
        idcBandwidthExport: null,
        idcIbRate: null,
        idcRoceRate: null,
        idcOpticalRate: null,
        Sort: null,
        updateUser: null,
        createUser: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        baseId: [
          { required: true, message: "数据中心ID不能为空", trigger: "blur" }
        ],
        dateNode: [
          { required: true, message: "日期节点不能为空", trigger: "blur" }
        ],
        createUser: [
          { required: true, message: "创建者不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询运力指标信息列表 */
    getList() {
      this.loading = true;
      listUseTransport(this.queryParams).then(response => {
        this.useTransportList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        baseId: null,
        dateNode: null,
        idcBandwidthExport: null,
        idcIbRate: null,
        idcRoceRate: null,
        idcOpticalRate: null,
        Sort: null,
        createTime: null,
        updateTime: null,
        updateUser: null,
        createUser: null,
        remark: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加运力指标信息";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getUseTransport(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改运力指标信息";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateUseTransport(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addUseTransport(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除运力指标信息编号为"' + ids + '"的数据项？').then(function() {
        return delUseTransport(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('bis/useTransport/export', {
        ...this.queryParams
      }, `useTransport_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
